@@ -85,6 +85,7 @@ tar_map_rep <- function(
   rep_workers = 1,
   combine = TRUE,
   delimiter = "_",
+  unlist = FALSE,
   tidy_eval = targets::tar_option_get("tidy_eval"),
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
@@ -113,6 +114,7 @@ tar_map_rep <- function(
     rep_workers = rep_workers,
     combine = combine,
     delimiter = delimiter,
+    unlist = unlist,
     tidy_eval = tidy_eval,
     packages = packages,
     library = library,
