@@ -33,6 +33,11 @@ targets::tar_test("tar_file()", {
   expect_equal(x$settings$format, "file")
 })
 
+targets::tar_test("tar_file_fast()", {
+  x <- suppressWarnings(tar_file_fast(x, 0))
+  expect_true(inherits(x, "tar_target"))
+})
+
 targets::tar_test("tar_rds()", {
   x <- tar_rds(x, 0)
   expect_true(inherits(x, "tar_target"))
@@ -51,6 +56,12 @@ targets::tar_test("tar_format_feather()", {
   expect_equal(x$settings$format, "feather")
 })
 
+targets::tar_test("tar_arrow_feather()", {
+  x <- tar_arrow_feather(x, 0)
+  expect_true(inherits(x, "tar_target"))
+  expect_equal(x$settings$format, "feather")
+})
+
 targets::tar_test("tar_parquet()", {
   x <- tar_parquet(x, 0)
   expect_true(inherits(x, "tar_target"))
